@@ -1,6 +1,6 @@
 package MARC::Moose::Parser::MarcxmlSaxHandler;
 BEGIN {
-  $MARC::Moose::Parser::MarcxmlSaxHandler::VERSION = '0.017';
+  $MARC::Moose::Parser::MarcxmlSaxHandler::VERSION = '0.018';
 }
 # ABSTRACT: SAX handler for parsing MARXML records
 
@@ -35,8 +35,8 @@ sub start_element {
         my $attr = $element->{Attributes};
         $self->{field} = MARC::Moose::Field::Std->new(
             tag  => $attr->{'{}tag'}{Value},
-            ind1 => $attr->{'{}ind1'}{Value},
-            ind2 => $attr->{'{}ind2'}{Value},
+            ind1 => $attr->{'{}ind1'}{Value} || '',
+            ind2 => $attr->{'{}ind2'}{Value} || '',
         );
     }
     elsif ( $name eq 'subfield' ) {
@@ -89,7 +89,7 @@ MARC::Moose::Parser::MarcxmlSaxHandler - SAX handler for parsing MARXML records
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 AUTHOR
 
